@@ -1,8 +1,6 @@
-# -*- coding=utf-8 -*-
 """
 Backports and helper functionality to support using new functionality.
 """
-from __future__ import absolute_import, print_function
 
 import atexit
 import contextlib
@@ -13,7 +11,6 @@ import re
 import sys
 import types
 
-import six
 from packaging import specifiers
 
 from .environment import MYPY_RUNNING
@@ -31,15 +28,10 @@ if sys.version_info[:2] < (3, 5):
 else:
     from tempfile import TemporaryDirectory
 
-if six.PY3:
-    from contextlib import ExitStack
-else:
-    from contextlib2 import ExitStack
-
+from contextlib import ExitStack
 
 if MYPY_RUNNING:
     from optparse import Values
-    from requests import Session
     from typing import (
         Any,
         Callable,
@@ -55,7 +47,10 @@ if MYPY_RUNNING:
         TypeVar,
         Union,
     )
-    from .utils import TShimmedPath, TShim, TShimmedFunc
+
+    from requests import Session
+
+    from .utils import TShim, TShimmedFunc, TShimmedPath
 
     TFinder = TypeVar("TFinder")
     TResolver = TypeVar("TResolver")
@@ -662,11 +657,16 @@ def get_package_finder(
         if python_versions:
             py_version_info_python = max(python_versions)
             py_version_info = tuple([int(part) for part in py_version_info_python])
-        target_python = target_python_builder(
-            platform=platform,
-            abi=abi,
-            implementation=implementation,
-            py_version_info=py_version_info,
+        target_python_args = {
+            "platform": platform,
+            "platforms": [platform] if platform else None,
+            "abi": abi,
+            "abis": [abi] if abi else None,
+            "implementation": implementation,
+            "py_version_info": py_version_info,
+        }
+        target_python = call_function_with_correct_args(
+            target_python_builder, **target_python_args
         )
         build_kwargs["target_python"] = target_python
     elif any(
@@ -762,10 +762,13 @@ def shim_unpack(
             unpack_kwargs["only_download"] = only_download
         if session is not None and "session" in required_args:
             unpack_kwargs["session"] = session
-        if "downloader" in required_args and downloader_provider is not None:
+        if (
+            "download" in required_args or "downloader" in required_args
+        ) and downloader_provider is not None:
+            arg_name = "download" if "download" in required_args else "downloader"
             assert session is not None
             assert progress_bar is not None
-            unpack_kwargs["downloader"] = downloader_provider(session, progress_bar)
+            unpack_kwargs[arg_name] = downloader_provider(session, progress_bar)
         return unpack_fn(**unpack_kwargs)  # type: ignore
 
 
@@ -904,13 +907,9 @@ def make_preparer(
     if options is not None and pip_options_created:
         for k, v in options_map.items():
             suppress_setattr(options, k, v, filter_none=True)
-    if all([session is None, install_cmd is None, session_is_required]):
-        raise TypeError(
-            "Preparer requires a session instance which was not supplied and cannot be "
-            "created without an InstallCommand."
-        )
-    elif all([session is None, session_is_required]):
-        session = get_session(install_cmd=install_cmd, options=options)
+    if session_is_required:
+        if session is None:
+            session = get_session(install_cmd=install_cmd, options=options)
         preparer_args["session"] = session
     if finder_is_required:
         finder = _ensure_finder(
@@ -923,12 +922,14 @@ def make_preparer(
         preparer_args["finder"] = finder
     if downloader_is_required:
         preparer_args["downloader"] = downloader_provider(session, progress_bar)
+    if "in_tree_build" in required_args:
+        preparer_args["in_tree_build"] = True
     req_tracker_fn = nullcontext if not req_tracker_fn else req_tracker_fn
     with req_tracker_fn() as tracker_ctx:
         if "req_tracker" in required_args:
             req_tracker = tracker_ctx if req_tracker is None else req_tracker
             preparer_args["req_tracker"] = req_tracker
-
+        preparer_args["lazy_wheel"] = True
         result = call_function_with_correct_args(preparer_fn, **preparer_args)
         yield result
 
@@ -1318,7 +1319,11 @@ def resolve(  # noqa:C901
             wheel_cache_provider(kwargs["cache_dir"], format_control)
         )  # type: ignore
         ireq.is_direct = True  # type: ignore
-        build_location_kwargs = {"build_dir": kwargs["build_dir"], "autodelete": True}
+        build_location_kwargs = {
+            "build_dir": kwargs["build_dir"],
+            "autodelete": True,
+            "parallel_builds": False,
+        }
         call_function_with_correct_args(ireq.build_location, **build_location_kwargs)
         if reqset_provider is None:
             raise TypeError(
@@ -1418,6 +1423,8 @@ def build_wheel(  # noqa:C901
     cache_dir=None,  # type: Optional[str]
     use_user_site=False,  # type: bool
     use_pep517=None,  # type: Optional[bool]
+    verify=False,  # type: bool
+    editable=False,  # type: bool
     format_control_provider=None,  # type: Optional[TShimmedFunc]
     wheel_cache_provider=None,  # type: Optional[TShimmedFunc]
     preparer_provider=None,  # type: Optional[TShimmedFunc]
@@ -1525,7 +1532,15 @@ def build_wheel(  # noqa:C901
         if req and not reqset and not output_dir:
             output_dir = get_ireq_output_path(wheel_cache, req)
         if not reqset and build_one_provider:
-            yield build_one_provider(req, output_dir, build_options, global_options)
+            build_one_kwargs = {
+                "req": req,
+                "output_dir": output_dir,
+                "verify": verify,
+                "editable": editable,
+                "build_options": build_options,
+                "global_options": global_options,
+            }
+            yield call_function_with_correct_args(build_one_provider, **build_one_kwargs)
         elif build_many_provider:
             yield build_many_provider(
                 reqset, wheel_cache, build_options, global_options, check_binary_allowed
